import os
import json
import pickle

import pytest

from evrouting.osm.imports import OSMGraph
from evrouting import charge
from evrouting.graph_tools import consumption_function_time_factory

STATIC_DIR = os.path.join(os.path.dirname(__file__), 'static')


@pytest.fixture
def large_graph():
    with open(os.path.join(STATIC_DIR, 'oberpfalz-latest.pck'), 'rb') as f:
        G: OSMGraph = pickle.load(f)
    G.rebuild_rtree()
    return G


@pytest.fixture
def charging_stations():
    with open(os.path.join(STATIC_DIR, 'charging_stations.json'), 'r') as f:
        charging_stations = json.load(f)
    return charging_stations


def test_debug(large_graph):
    """Full tank is enough to get there. Must be equal to shortest path."""
    G = large_graph
    _s = '2151728389'
    _t = '4383892857'

    consumption = 1000 * 0.1
    c = consumption_function_time_factory(consumption)
    result = charge.routing.shortest_path(
        G=G,
        charging_stations=G.charging_stations,
        s=_s,
        t=_t,
        initial_soc=300000,  # > cost_path
        final_soc=0,
        capacity=300000,
        c=c
    )

    assert result.trip_time is not None
